@@ -31,24 +31,14 @@ static GtkWidget   *act_params;
 static GtkWidget   *act_mod;
 static GtkWidget   *act_clist;
 
-#define VER_E16_OLD 0
-#define VER_E16_8   1
-static int          e16_ver = VER_E16_OLD;
-
 static gchar       *e_ipc_msg = NULL;
 static char         dont_update = 0;
 static int          last_row = 0;
 static int          real_rows = 0;
 
-/* Various UI text strings */
-#define TXT_SELECT(old, new) ((e16_ver==VER_E16_OLD) ? old : new)
-#define TXT_PARAMETERS_USED TXT_SELECT("Parameters Used", "Command")
-#define TXT_PARAMETERS      TXT_SELECT("Parameters:", "Command:")
-
 typedef struct
 {
    const char         *text;
-   gint                id;
    gchar               param_tpe;
    const char         *params;
    const char         *command;
@@ -81,99 +71,87 @@ static const char  *mod_str[] = {
 
 /* *INDENT-OFF* */
 static const ActionOpt actions_default[] = {
-    {"Run command", 1, 1, NULL, "exec "},
+    {"Run command", 1, NULL, "exec "},
 
-    {"Restart Enlightenment", 7, 0, "restart", "restart"},
-    {"Exit Enlightenment", 7, 0, NULL, "exit"},
+    {"Restart Enlightenment", 0, "restart", "restart"},
+    {"Exit Enlightenment", 0, NULL, "exit"},
 
-    {"Goto Next Desktop", 15, 0, NULL, "desk next"},
-    {"Goto Previous Deskop", 16, 0, NULL, "desk prev"},
-    {"Goto Desktop", 42, 2, NULL, "desk goto "},
-    {"Raise Desktop", 17, 0, NULL, "desk raise"},
-    {"Lower Desktop", 18, 0, NULL, "desk lower"},
-    {"Reset Desktop In Place", 21, 0, NULL, "desk this"},
+    {"Goto Next Desktop", 0, NULL, "desk next"},
+    {"Goto Previous Deskop", 0, NULL, "desk prev"},
+    {"Goto Desktop", 2, NULL, "desk goto "},
+    {"Raise Desktop", 0, NULL, "desk raise"},
+    {"Lower Desktop", 0, NULL, "desk lower"},
+    {"Reset Desktop In Place", 0, NULL, "desk this"},
 
-    {"Toggle Deskrays", 43, 0, NULL, NULL},
+    {"Cleanup Windows", 0, NULL, "misc arrange size"},
 
-    {"Cleanup Windows", 8, 0, NULL, "misc arrange size"},
+    {"Move mouse pointer to next screen", 0, NULL, "warp screen"},
 
-    {"Scroll Windows to left", 48, 0, "-16 0", NULL},
-    {"Scroll Windows to right", 48, 0, "16 0", NULL},
-    {"Scroll Windows up", 48, 0, "0 -16", NULL},
-    {"Scroll Windows down", 48, 0, "0 16", NULL},
-    {"Scroll Windows by [X Y] pixels", 48, 3, NULL, NULL},
+    {"Move mouse pointer to left", 0, "-1 0", "warp rel -1 0"},
+    {"Move mouse pointer to right", 0, "1 0", "warp rel 1 0"},
+    {"Move mouse pointer up", 0, "0 -1", "warp rel 0 -1"},
+    {"Move mouse pointer down", 0, "0 1", "warp rel 0 1"},
+    {"Move mouse pointer by [X Y]", 3, NULL, "warp rel "},
 
-    {"Move mouse pointer to next screen", -1, 0, NULL, "warp screen"},
+    {"Goto Desktop area [X Y]", 3, NULL, "area goto"},
+    {"Move to Desktop area on the left", 0, "-1 0", "area move -1 0"},
+    {"Move to Desktop area on the right", 0, "1 0", "area move 1 0"},
+    {"Move to Desktop area above", 0, "0 -1", "area move 0 -1"},
+    {"Move to Desktop area below", 0, "0 1", "area move 0 1"},
 
-    {"Move mouse pointer to left", 66, 0, "-1 0", "warp rel -1 0"},
-    {"Move mouse pointer to right", 66, 0, "1 0", "warp rel 1 0"},
-    {"Move mouse pointer up", 66, 0, "0 -1", "warp rel 0 -1"},
-    {"Move mouse pointer down", 66, 0, "0 1", "warp rel 0 1"},
-    {"Move mouse pointer by [X Y]", 66, 3, NULL, "warp rel "},
+    {"Raise Window", 0, NULL, "wop * raise"},
+    {"Lower Window", 0, NULL, "wop * lower"},
+    {"Close Window", 0, NULL, "wop * close"},
+    {"Annihilate Window", 0, NULL, "wop * kill"},
+    {"Stick / Unstick Window", 0, NULL, "wop * stick"},
+    {"Iconify Window", 0, NULL, "wop * iconify"},
+    {"Shade / Unshade Window", 0, NULL, "wop * shade"},
+    {"Maximise Height of Window", 0, "conservative", "wop * th conservative"},
+    {"Maximise Height of Window to available space", 0, "available", "wop * th available"},
+    {"Maximise Height of Window to whole screen", 0, NULL, "wop * th"},
+    {"Maximise Width of Window", 0, "conservative", "wop * tw conservative"},
+    {"Maximise Width of Window to available space", 0, "available", "wop * tw available"},
+    {"Maximise Width of Window to whole screen", 0, NULL, "wop * tw"},
+    {"Maximise Size of Window", 0, "conservative", "wop * ts conservative"},
+    {"Maximise Size of Window to available space", 0, "available", "wop * ts available"},
+    {"Maximise Size of Window to whole screen", 0, NULL, "wop * ts"},
+    {"Toggle Window fullscreen state", 0, NULL, "wop * fullscreen"},
+    {"Toggle Window zoom state", 0, NULL, "wop * zoom"},
+    {"Send window to next desktop", 0, NULL, "wop * desk next"},
+    {"Send window to previous desktop", 0, NULL, "wop * desk prev"},
+    {"Switch focus to next window", 0, NULL, "focus next"},
+    {"Switch focus to previous window", 0, NULL, "focus prev"},
+    {"Glue / Unglue Window to Desktop screen", 0, NULL, "wop * no_user_move"},
+    {"Set Window layer to On Top", 0, "20", "wop * layer 20"},
+    {"Set Window layer to Above", 0, "6", "wop * layer 6"},
+    {"Set Window layer to Normal", 0, "4", "wop * layer 4"},
+    {"Set Window layer to Below", 0, "2", "wop * layer 2"},
+    {"Set Window layer", 2, NULL, "wop * layer "},
+    {"Move Window to area on left", 0, "-1 0", "wop * area move -1 0"},
+    {"Move Window to area on right", 0, "1 0", "wop * area move 1 0"},
+    {"Move Window to area above", 0, "0 -1", "wop * area move 0 -1"},
+    {"Move Window to area below", 0, "0 1", "wop * area move 0 1"},
+    {"Move Window by area [X Y]", 3, NULL, "wop * area "},
 
-    {"Goto Desktop area [X Y]", 62, 3, NULL, "area goto"},
-    {"Move to Desktop area on the left", 63, 0, "-1 0", "area move -1 0"},
-    {"Move to Desktop area on the right", 63, 0, "1 0", "area move 1 0"},
-    {"Move to Desktop area above", 63, 0, "0 -1", "area move 0 -1"},
-    {"Move to Desktop area below", 63, 0, "0 1", "area move 0 1"},
+    {"Set Window border style to the Default", 0, "DEFAULT", "wop * border DEFAULT"},
+    {"Set Window border style to the Borderless", 0, "BORDERLESS", "wop * border BORDERLESS"},
 
-    {"Raise Window", 5, 0, NULL, "wop * raise"},
-    {"Lower Window", 6, 0, NULL, "wop * lower"},
-    {"Close Window", 13, 0, NULL, "wop * close"},
-    {"Annihilate Window", 14, 0, NULL, "wop * kill"},
-    {"Stick / Unstick Window", 20, 0, NULL, "wop * stick"},
-    {"Iconify Window", 46, 0, NULL, "wop * iconify"},
-    {"Shade / Unshade Window", 49, 0, NULL, "wop * shade"},
-    {"Maximise Height of Window", 50, 0, "conservative", "wop * th conservative"},
-    {"Maximise Height of Window to available space", 50, 0, "available", "wop * th available"},
-    {"Maximise Height of Window to whole screen", 50, 0, NULL, "wop * th"},
-    {"Maximise Width of Window", 51, 0, "conservative", "wop * tw conservative"},
-    {"Maximise Width of Window to available space", 51, 0, "available", "wop * tw available"},
-    {"Maximise Width of Window to whole screen", 51, 0, NULL, "wop * tw"},
-    {"Maximise Size of Window", 52, 0, "conservative", "wop * ts conservative"},
-    {"Maximise Size of Window to available space", 52, 0, "available", "wop * ts available"},
-    {"Maximise Size of Window to whole screen", 52, 0, NULL, "wop * ts"},
-    {"Toggle Window fullscreen state", -1, 0, NULL, "wop * fullscreen"},
-    {"Toggle Window zoom state", -1, 0, NULL, "wop * zoom"},
-    {"Send window to next desktop", 53, 0, NULL, "wop * desk next"},
-    {"Send window to previous desktop", 54, 0, NULL, "wop * desk prev"},
-    {"Switch focus to next window", 58, 0, NULL, "focus next"},
-    {"Switch focus to previous window", 59, 0, NULL, "focus prev"},
-    {"Glue / Unglue Window to Desktop screen", 64, 0, NULL, "wop * no_user_move"},
-    {"Set Window layer to On Top", 65, 0, "20", "wop * layer 20"},
-    {"Set Window layer to Above", 65, 0, "6", "wop * layer 6"},
-    {"Set Window layer to Normal", 65, 0, "4", "wop * layer 4"},
-    {"Set Window layer to Below", 65, 0, "2", "wop * layer 2"},
-    {"Set Window layer", 65, 2, NULL, "wop * layer "},
-    {"Move Window to area on left", 0, 0, "-1 0", "wop * area move -1 0"},
-    {"Move Window to area on right", 0, 0, "1 0", "wop * area move 1 0"},
-    {"Move Window to area above", 0, 0, "0 -1", "wop * area move 0 -1"},
-    {"Move Window to area below", 0, 0, "0 1", "wop * area move 0 1"},
-    {"Move Window by area [X Y]", 0, 3, NULL, "wop * area "},
+    {"Forget everything about Window", 0, "none", "wop * snap none"},
+    {"Remember all Window settings", 0, NULL, "wop * snap all"},
+    {"Remember Window Border", 0, "border", "wop * snap border"},
+    {"Remember Window Desktop", 0, "desktop", "wop * snap desktop"},
+    {"Remember Window Desktop Area", 0, "area", "wop * snap area"},
+    {"Remember Window Size", 0, "size", "wop * snap size"},
+    {"Remember Window Location", 0, "location", "wop * snap location"},
+    {"Remember Window Layer", 0, "layer", "wop * snap layer"},
+    {"Remember Window Stickyness", 0, "sticky", "wop * snap sticky"},
+    {"Remember Window Shadedness", 0, "shade", "wop * snap shade"},
 
-    {"Set Window border style to the Default", 69, 0, "DEFAULT", "wop * border DEFAULT"},
-    {"Set Window border style to the Borderless", 69, 0, "BORDERLESS", "wop * border BORDERLESS"},
+    {"Show Root Menu", 0, "ROOT_2", "menus show ROOT_2"},
+    {"Show Winops Menu", 0, "WINOPS_MENU", "menus show WINOPS_MENU"},
+    {"Show Named Menu", 1, NULL, "menus show "},
 
-    {"Forget everything about Window", 55, 0, "none", "wop * snap none"},
-    {"Remember all Window settings", 55, 0, NULL, "wop * snap all"},
-    {"Remember Window Border", 55, 0, "border", "wop * snap border"},
-    {"Remember Window Desktop", 55, 0, "desktop", "wop * snap desktop"},
-    {"Remember Window Desktop Area", 55, 0, "area", "wop * snap area"},
-    {"Remember Window Size", 55, 0, "size", "wop * snap size"},
-    {"Remember Window Location", 55, 0, "location", "wop * snap location"},
-    {"Remember Window Layer", 55, 0, "layer", "wop * snap layer"},
-    {"Remember Window Stickyness", 55, 0, "sticky", "wop * snap sticky"},
-    {"Remember Window Shadedness", 55, 0, "shade", "wop * snap shade"},
-
-    {"Show Root Menu", 9, 0, "ROOT_2", "menus show ROOT_2"},
-    {"Show Winops Menu", 9, 0, "WINOPS_MENU", "menus show WINOPS_MENU"},
-    {"Show Named Menu", 9, 1, NULL, "menus show "},
-
-    {"Goto Linear Area", 70, 2, NULL, NULL},
-    {"Previous Linear Area", 71, 0, "-1", NULL},
-    {"Next Linear Area", 71, 0, "1", NULL},
-
-    {NULL, 0, 0, NULL, NULL}
+    {NULL, 0, NULL, NULL}
 };
 /* *INDENT-ON* */
 
@@ -189,35 +167,11 @@ match_action_by_binding(int opcode, const char *params)
 
    for (k = 0; actions[k].text; k++)
      {
-	if (e16_ver > VER_E16_OLD)
-	  {
-	     if (!actions[k].command)	/* Not avaliable in 16.8 */
-		continue;
+	len = strlen(actions[k].command);
+	if (strncmp(actions[k].command, params, len))
+	   continue;
 
-	     len = strlen(actions[k].command);
-	     if (strncmp(actions[k].command, params, len))
-		continue;
-
-	     return k;
-	  }
-	else
-	  {
-	     if (opcode != actions[k].id)
-		continue;
-
-	     if (*params == '\0' && !actions[k].params)
-		return k;	/* No parameters */
-
-	     if ((actions[k].param_tpe == 0) && (actions[k].params))
-	       {
-		  if (!strcmp(params, actions[k].params))
-		     return k;
-	       }
-	     else
-	       {
-		  return k;
-	       }
-	  }
+	return k;
      }
 
    return -1;
@@ -293,7 +247,7 @@ e_cb_modifier(GtkWidget * widget __UNUSED__, gpointer data)
 {
    gint                value;
 
-   value = (gint) data;
+   value = (gint) (glong) data;
    gtk_clist_set_text(GTK_CLIST(clist), last_row, 0, mod_str[value]);
 }
 
@@ -327,18 +281,10 @@ change_action(GtkWidget * my_clist __UNUSED__, gint row, gint column __UNUSED__,
 	gtk_entry_set_text(GTK_ENTRY(act_params), "");
      }
 
-   if (e16_ver != VER_E16_OLD)
-     {
-	if (actions[k].command)
-	   gtk_entry_set_text(GTK_ENTRY(act_params), actions[k].command);
-	else
-	   gtk_entry_set_text(GTK_ENTRY(act_params), "* Not available *");
-     }
+   if (actions[k].command)
+      gtk_entry_set_text(GTK_ENTRY(act_params), actions[k].command);
    else
-     {
-	if (actions[k].params)
-	   gtk_entry_set_text(GTK_ENTRY(act_params), actions[k].params);
-     }
+      gtk_entry_set_text(GTK_ENTRY(act_params), "* Not available *");
    gtk_clist_set_text(GTK_CLIST(clist), last_row, 2, actions[k].text);
    gtk_clist_set_text(GTK_CLIST(clist), last_row, 3,
 		      gtk_entry_get_text(GTK_ENTRY(act_params)));
@@ -378,7 +324,6 @@ on_save_data(GtkWidget * widget __UNUSED__, gpointer data __UNUSED__)
 	char               *key;
 	char               *mod;
 	int                 modifier = 0;
-	int                 action_id = 0;
 	int                 j;
 
 	gtk_clist_get_text(GTK_CLIST(clist), i, 0, &mod);
@@ -392,34 +337,11 @@ on_save_data(GtkWidget * widget __UNUSED__, gpointer data __UNUSED__)
 	gtk_clist_get_text(GTK_CLIST(clist), i, 1, &key);
 	gtk_clist_get_text(GTK_CLIST(clist), i, 2, &action);
 	j = match_action_by_selection(action);
-	action_id = (j >= 0) ? actions[j].id : -1;
 	gtk_clist_get_text(GTK_CLIST(clist), i, 3, &params);
 
-	if (e16_ver > VER_E16_OLD)
-	  {
-	     if (*params == '*')
-		continue;
-	     snprintf(tmp, sizeof(tmp), "%s %i %i %s\n", key, modifier, 0,
-		      params);
-	  }
-	else if (*params != '\0')
-	  {
-	     if (action_id < 0)
-		continue;
-
-	     if (action_id == 9)
-	       {
-		  snprintf(params_tmp, sizeof(params_tmp), "%s %s", "named",
-			   params);
-		  params = (char *)params_tmp;
-	       }
-	     snprintf(tmp, sizeof(tmp), "%s %i %i %s\n", key, modifier,
-		      action_id, params);
-	  }
-	else
-	  {
-	     snprintf(tmp, sizeof(tmp), "%s %i %i\n", key, modifier, action_id);
-	  }
+	if (*params == '*')
+	   continue;
+	snprintf(tmp, sizeof(tmp), "%s %i %i %s\n", key, modifier, 0, params);
 	buf = dupcat(buf, tmp);
      }
 
@@ -696,7 +618,7 @@ create_list_window(void)
    gtk_clist_set_column_title(GTK_CLIST(clist), 0, "Modifier");
    gtk_clist_set_column_title(GTK_CLIST(clist), 1, "Key");
    gtk_clist_set_column_title(GTK_CLIST(clist), 2, "Action to Perform");
-   gtk_clist_set_column_title(GTK_CLIST(clist), 3, TXT_PARAMETERS_USED);
+   gtk_clist_set_column_title(GTK_CLIST(clist), 3, "Command");
    gtk_clist_column_titles_show(GTK_CLIST(clist));
    gtk_signal_connect(GTK_OBJECT(clist), "select_row",
 		      GTK_SIGNAL_FUNC(selection_made), NULL);
@@ -802,7 +724,7 @@ create_list_window(void)
 		    GTK_FILL, (GtkAttachOptions) (0), 0, 0);
 
    alignment = gtk_alignment_new(1.0, 0.5, 0, 0);
-   label = gtk_label_new(TXT_PARAMETERS);
+   label = gtk_label_new("Command:");
    gtk_container_add(GTK_CONTAINER(alignment), label);
    gtk_widget_show(alignment);
    gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
@@ -840,7 +762,8 @@ create_list_window(void)
 	   mi = gtk_menu_item_new_with_label(mod_str[i]);
 	   gtk_widget_show(mi);
 	   gtk_signal_connect(GTK_OBJECT(mi), "activate",
-			      GTK_SIGNAL_FUNC(e_cb_modifier), (gpointer) i);
+			      GTK_SIGNAL_FUNC(e_cb_modifier),
+			      (gpointer) (glong) i);
 	   gtk_menu_append(GTK_MENU(m), mi);
 	}
    }
@@ -883,8 +806,6 @@ create_list_window(void)
 
       for (k = row = 0; (actions[k].text); k++)
 	{
-	   if (e16_ver == VER_E16_OLD && actions[k].id < 0)
-	      continue;
 	   stuff[0] = actions[k].text;
 	   gtk_clist_append(GTK_CLIST(act_clist), (char **)stuff);
 	   action_index_to_row[k] = row;
@@ -934,34 +855,6 @@ receive_ipc_msg(gchar * msg)
    gtk_main_quit();
 }
 
-static int
-get_e16_version(void)
-{
-   char               *msg;
-   const char         *s;
-   int                 ver, minor;
-
-   ver = VER_E16_OLD;
-
-   CommsSend("ver");
-   msg = wait_for_ipc_msg();
-   if (!msg)
-      goto done;
-
-   s = strstr(msg, "0.16.");
-   if (!s)
-      goto done;
-
-   sscanf(s, "0.16.%d", &minor);
-   if (minor >= 8)
-      ver = VER_E16_8;
-
- done:
-   if (msg)
-      free(msg);
-   return ver;
-}
-
 static void
 load_actions(void)
 {
@@ -974,14 +867,11 @@ load_actions(void)
 
    actions = actions_default;
 
-   if (e16_ver == VER_E16_OLD)
-      return;
-
    /* FIXME - Should be fetched via IPC. */
 
    s = getenv("EROOT");
    if (!s)
-      return;
+      s = DATADIR "/e16";	/* Default location */
 
    snprintf(kbdb, sizeof(kbdb), "%s/config/e16keyedit.db", s);
 
@@ -1025,6 +915,8 @@ load_actions(void)
 	     fclose(f);
 	     return;
 	  }
+	if (!command[0])
+	   continue;
 #if DEBUG > 0
 	printf("n=%d t=%s o=%d c=%s\n", n, text, opt, command);
 #endif
@@ -1033,8 +925,7 @@ load_actions(void)
 	memset(pao + nao, 0, sizeof(ActionOpt));
 	pao[nao].text = strdup(text);
 	pao[nao].param_tpe = opt;
-	if (command[0])
-	   pao[nao].command = strdup(command);
+	pao[nao].command = strdup(command);
 	nao++;
      }
    fclose(f);
@@ -1103,8 +994,6 @@ main(int argc, char *argv[])
 	     "it remotely.");
 #endif
 
-   e16_ver = get_e16_version();
-
    load_actions();
 
    lister = create_list_window();
